/*
 * ******************************************************************************************
 *
 * File		: apb_i2c_dev.c
 * Author	: GOWIN
 * Function	: Device definition of APB I2C
 *
 * ******************************************************************************************
 */


// Includes ---------------------------------------------------------------------------------
#include "apb_i2c_dev.h"


// Definitions  -----------------------------------------------------------------------------

// Get capabilities
APB_I2C_CAPABILITIES apb_i2c1_get_capabilities(void)
{
	return DriverCapabilities;
}

// Initialized
int apb_i2c1_initialize(APB_I2C_SignalEvent_t cb_event)
{
	return apb_i2cx_initialize(cb_event, &APB_I2C1_Resources);
}

// Uninitialized
int apb_i2c1_uninitialize(void)
{
	return apb_i2cx_uninitialize(&APB_I2C1_Resources);
}

// Power control
int apb_i2c1_power_control(APB_I2C_POWER_STATE state)
{
	return apb_i2cx_power_control(state, &APB_I2C1_Resources);
}

// Master transmit data
int apb_i2c1_master_transmit(unsigned int addr, const unsigned char* data, unsigned int num, bool xfer_pending)
{
	return apb_i2cx_master_transmit(addr, data, num, xfer_pending, &APB_I2C1_Resources);
}

// Master receive data
int apb_i2c1_master_receive(unsigned int addr, unsigned char* data, unsigned int num, bool xfer_pending)
{
	return apb_i2cx_master_receive(addr, data, num, xfer_pending, &APB_I2C1_Resources);
}

// Slave transmit data
int apb_i2c1_slave_transmit(const unsigned char* data, unsigned int num)
{
	return apb_i2cx_slave_transmit(data, num, &APB_I2C1_Resources);
}

// Slave receive data
int apb_i2c1_slave_receive(unsigned char* data, unsigned int num)
{
	return apb_i2cx_slave_receive(data, num, &APB_I2C1_Resources);
}

// Get data count
unsigned int apb_i2c1_get_datacount(void)
{
	return apb_i2cx_get_datacount(&APB_I2C1_Resources);
}

// Control command
int apb_i2c1_control(unsigned int control, unsigned int arg)
{
	return apb_i2cx_control(control, arg, 0, &APB_I2C1_Resources);
}

// Get status
APB_I2C_STATUS apb_i2c1_get_status(void)
{
	return apb_i2cx_getstatus(&APB_I2C1_Resources);
}

#if (APB_I2C1_DMA_EN == 1)
// DMA TX event
void apb_i2c1_dma_tx_event (unsigned int event)
{
	apb_i2cx_dma_tx_event(event, &APB_I2C1_Resources);
}

// DMA RX event
void apb_i2c1_dma_rx_event (unsigned int event)
{
	apb_i2cx_dma_rx_event(event, &APB_I2C1_Resources);
}
#endif

// APB I2C1 interrupt handler
void apb_i2c1_irq_handler(void)
{
	apb_i2cx_irq_handler(&APB_I2C1_Resources);
}
