/*
 * ******************************************************************************************
 *
 * File		: apb_i2c_dev.h
 * Author	: GOWIN
 * Function	: Device definition of APB I2C
 *
 * ******************************************************************************************
 */

#ifndef __APB_I2C_DEV_H__
#define __APB_I2C_DEV_H__


#ifdef __cplusplus
extern "C" {
#endif


// Includes ---------------------------------------------------------------------------------
#include "apb_i2c_driver.h"
#include "platform.h"


// Definitions ------------------------------------------------------------------------------

/*************************************************************************************
 * An APB I2C device "APB I2C1" is defined as a user template.
 * User can define more APB I2C devices.
 *************************************************************************************/

/*************************************************************************************
 * "X" represents user customized.
 *************************************************************************************/

// APB I2C device
#define APB_I2C1_BASE					APB_EXT_BASE/*X*/						// APB I2C1 address definition
#define APB_I2C1						((APB_I2C_RegDef *) APB_I2C1_BASE )		// APB I2C1 register definition

#define IRQ_APB_I2C1_SOURCE				IRQ_GP0_SOURCE/*X*/						// APB I2C1 interrupt source
#define apb_i2c1_irq_handler			gp0_irq_handler/*X*/					// APB I2C1 interrupt handler


// APB I2C1 with DMA
#if (APB_I2C_DMA_EN == 0)
#define APB_I2C1_DMA_EN					0
#else
#define APB_I2C1_DMA_EN              	1/*X*/		// Enable/disable APB I2C1 DMA. X: 1: enable; 0: disable.
#endif
// DMA TX
#define APB_I2C1_DMA_TX_CH              0/*X*/		// DMA channel number for APB I2C1 TX
#define APB_I2C1_DMA_TX_REQID           0/*X*/		// DMA request ID for APB I2C1 TX
// DMA RX
#define APB_I2C1_DMA_RX_CH              1/*X*/		// DMA channel number for APB I2C1 RX
#define APB_I2C1_DMA_RX_REQID           1/*X*/		// DMA request ID for APB I2C1 RX


// Driver Capabilities
static const APB_I2C_CAPABILITIES DriverCapabilities =
{
	1
};

// APB I2C1 Control Information
static APB_I2C_INFO APB_I2C1_Info = {0};

#if (APB_I2C1_DMA_EN == 1)
// DMA TX
void apb_i2c1_dma_tx_event (unsigned int event);
static APB_I2C_DMA apb_i2c1_dma_tx =
{
	APB_I2C1_DMA_TX_CH,
	APB_I2C1_DMA_TX_REQID,
	apb_i2c1_dma_tx_event
};

// DMA RX
void apb_i2c1_dma_rx_event (unsigned int event);
static APB_I2C_DMA apb_i2c1_dma_rx =
{
	APB_I2C1_DMA_RX_CH,
	APB_I2C1_DMA_RX_REQID,
	apb_i2c1_dma_rx_event
};
#endif

// APB I2C1 Resources
static APB_I2C_RESOURCES APB_I2C1_Resources =
{
	APB_I2C1,
	IRQ_APB_I2C1_SOURCE,
#if (APB_I2C1_DMA_EN == 1)
	&apb_i2c1_dma_tx,
	&apb_i2c1_dma_rx,
#endif
	&APB_I2C1_Info
};


// *** Functions *** //

// Initialized
int apb_i2c1_initialize(APB_I2C_SignalEvent_t cb_event);

// Uninitialized
int apb_i2c1_uninitialize(void);

// Get capabilities
APB_I2C_CAPABILITIES apb_i2c1_get_capabilities(void);

// Power control
int apb_i2c1_power_control(APB_I2C_POWER_STATE state);

// Master transmit data
int apb_i2c1_master_transmit(unsigned int addr, const unsigned char* data, unsigned int num, bool xfer_pending);

// Master receive data
int apb_i2c1_master_receive(unsigned int addr, unsigned char* data, unsigned int num, bool xfer_pending);

// Slave transmit data
int apb_i2c1_slave_transmit(const unsigned char* data, unsigned int num);

// Slave receive data
int apb_i2c1_slave_receive(unsigned char* data, unsigned int num);

// Get data count
unsigned int apb_i2c1_get_datacount(void);

// Control command
int apb_i2c1_control(unsigned int control, unsigned int arg);

// Get status
APB_I2C_STATUS apb_i2c1_get_status(void);

#if (APB_I2C1_DMA_EN == 1)
// DMA TX event
void apb_i2c1_dma_tx_event (unsigned int event);

// DMA RX event
void apb_i2c1_dma_rx_event (unsigned int event);
#endif

// APB I2C1 interrupt handler
void apb_i2c1_irq_handler(void);


// As this template, user can define more APB I2C devices.


#ifdef __cplusplus
}
#endif


#endif	/* __APB_I2C_DEV_H__ */
