/*
 * ******************************************************************************************
 *
 * File		: apb_i2c_driver.h
 * Author	: GOWIN
 * Function	: Driver definition of APB I2C
 *
 * ******************************************************************************************
 */

#ifndef __APB_I2C_DRIVER_H__
#define __APB_I2C_DRIVER_H__


#ifdef __cplusplus
extern "C" {
#endif


// Includes ---------------------------------------------------------------------------------
#include "apb_i2c.h"
#include <stdbool.h>


// Definitions ------------------------------------------------------------------------------

// Initializes
int apb_i2cx_initialize(APB_I2C_SignalEvent_t cb_event, APB_I2C_RESOURCES* i2c);

// Uninitialized
int apb_i2cx_uninitialize(APB_I2C_RESOURCES* i2c);

// Get capabilities
APB_I2C_CAPABILITIES apb_i2cx_get_capabilities(APB_I2C_RESOURCES* i2c);

// Power control
int apb_i2cx_power_control(APB_I2C_POWER_STATE state, APB_I2C_RESOURCES* i2c);

// Master mode know how many bytes to transmit
int apb_i2cx_master_transmit(unsigned int addr, const unsigned char* data, unsigned int num, bool xfer_pending, APB_I2C_RESOURCES* i2c);

// Master mode know how many bytes to receive
int apb_i2cx_master_receive(unsigned int addr, unsigned char* data, unsigned int num, bool xfer_pending, APB_I2C_RESOURCES* i2c);

// Slave mode unknown how many bytes to TX, so TX 1 byte each time until complete or nack_assert
int apb_i2cx_slave_transmit(const unsigned char* data, unsigned int num, APB_I2C_RESOURCES* i2c);

// Slave mode unknown how many bytes to RX, so RX FIFO-full byte each time until complete
int apb_i2cx_slave_receive(unsigned char* data, unsigned int num, APB_I2C_RESOURCES* i2c);

// Get data count
unsigned int apb_i2cx_get_datacount(APB_I2C_RESOURCES* i2c);

// Control
int apb_i2cx_control(unsigned int control, unsigned int arg0, unsigned int arg1, APB_I2C_RESOURCES* i2c);

// Get status
APB_I2C_STATUS apb_i2cx_getstatus(APB_I2C_RESOURCES* i2c);

// Interrupt handler
void apb_i2cx_irq_handler(APB_I2C_RESOURCES* i2c);

#if (APB_I2C_DMA_EN == 1)
// DMA TX
void apb_i2cx_dma_tx_event (unsigned int event, APB_I2C_RESOURCES* i2c);

// DMA RX
void apb_i2cx_dma_rx_event (unsigned int event, APB_I2C_RESOURCES* i2c);
#endif


#ifdef __cplusplus
}
#endif


#endif	/* __APB_I2C_DRIVER_H__ */
